Index: /trunk/src/VBox/Frontends/VirtualBox/src/selector/UISelectorWindow.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/selector/UISelectorWindow.cpp	(revision 68229)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/selector/UISelectorWindow.cpp	(revision 68230)
@@ -46,4 +46,5 @@
 # include "UISlidingWidget.h"
 # include "UISpacerWidgets.h"
+# include "UITabBar.h"
 # include "UIToolBar.h"
 # include "UIVMLogViewer.h"
@@ -118,4 +119,8 @@
 #endif
     , m_pToolBar(0)
+    , m_pTabBarMachine(0)
+    , m_pTabBarGlobal(0)
+    , m_pActionTabBarMachine(0)
+    , m_pActionTabBarGlobal(0)
     , m_pToolbarTools(0)
     , m_pPaneChooser(0)
@@ -152,4 +157,16 @@
 }
 #endif /* VBOX_WS_X11 && QT_VERSION >= 0x050000 */
+
+void UISelectorWindow::sltHandleShowTabBarMachine()
+{
+    m_pActionTabBarGlobal->setVisible(false);
+    m_pActionTabBarMachine->setVisible(true);
+}
+
+void UISelectorWindow::sltHandleShowTabBarGlobal()
+{
+    m_pActionTabBarMachine->setVisible(false);
+    m_pActionTabBarGlobal->setVisible(true);
+}
 
 void UISelectorWindow::sltShowSelectorWindowContextMenu(const QPoint &position)
@@ -1800,4 +1817,26 @@
         m_pToolBar->addWidget(new UIHorizontalSpacerWidget);
 
+        /* Create Machine tab-bar: */
+        m_pTabBarMachine = new UITabBar;
+        AssertPtrReturnVoid(m_pTabBarMachine);
+        {
+            /* Configure tab-bar: */
+            m_pTabBarMachine->setContentsMargins(0, 0, 10, 0);
+
+            /* Add into toolbar: */
+            m_pActionTabBarMachine = m_pToolBar->addWidget(m_pTabBarMachine);
+        }
+
+        /* Create Global tab-bar: */
+        m_pTabBarGlobal = new UITabBar;
+        AssertPtrReturnVoid(m_pTabBarGlobal);
+        {
+            /* Configure tab-bar: */
+            m_pTabBarGlobal->setContentsMargins(0, 0, 10, 0);
+
+            /* Add into toolbar: */
+            m_pActionTabBarGlobal = m_pToolBar->addWidget(m_pTabBarGlobal);
+        }
+
         /* Create Tools toolbar: */
         m_pToolbarTools = new UIToolsToolbar(actionPool());
@@ -1806,4 +1845,9 @@
             /* Configure toolbar: */
             m_pToolbarTools->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::MinimumExpanding);
+            connect(m_pToolbarTools, &UIToolsToolbar::sigShowTabBarMachine,
+                    this, &UISelectorWindow::sltHandleShowTabBarMachine);
+            connect(m_pToolbarTools, &UIToolsToolbar::sigShowTabBarGlobal,
+                    this, &UISelectorWindow::sltHandleShowTabBarGlobal);
+            m_pToolbarTools->setTabBars(m_pTabBarMachine, m_pTabBarGlobal);
 
             /* Create exclusive action-group: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/selector/UISelectorWindow.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/selector/UISelectorWindow.h	(revision 68229)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/selector/UISelectorWindow.h	(revision 68230)
@@ -40,4 +40,5 @@
 #endif
 class UISlidingWidget;
+class UITabBar;
 class UIToolBar;
 class UIToolsToolbar;
@@ -82,4 +83,9 @@
     void QT_VERSION_NOT_DEFINED
 #endif /* VBOX_WS_X11 && QT_VERSION >= 0x050000 */
+
+    /** Handles request to show Machine tab-bar. */
+    void sltHandleShowTabBarMachine();
+    /** Handles request to show Global tab-bar. */
+    void sltHandleShowTabBarGlobal();
 
     /** Handles selector-window context-menu call for passed @a position. */
@@ -333,8 +339,18 @@
 #ifndef VBOX_WS_MAC
     /** Holds the main bar instance. */
-    UIMainBar      *m_pBar;
+    UIMainBar *m_pBar;
 #endif
     /** Holds the main toolbar instance. */
-    UIToolBar      *m_pToolBar;
+    UIToolBar *m_pToolBar;
+
+    /** Holds the Machine tab-bar instance. */
+    UITabBar *m_pTabBarMachine;
+    /** Holds the Global tab-bar instance. */
+    UITabBar *m_pTabBarGlobal;
+    /** Holds the Machine tab-bar action reference. */
+    QAction *m_pActionTabBarMachine;
+    /** Holds the Global tab-bar action reference. */
+    QAction *m_pActionTabBarGlobal;
+
     /** Holds the Tools-toolbar instance. */
     UIToolsToolbar *m_pToolbarTools;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/selector/UIToolsToolbar.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/selector/UIToolsToolbar.cpp	(revision 68229)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/selector/UIToolsToolbar.cpp	(revision 68230)
@@ -42,11 +42,31 @@
     : QWidget(pParent)
     , m_pActionPool(pActionPool)
-    , m_pLayoutMain(0)
     , m_pTabBarMachine(0)
     , m_pTabBarGlobal(0)
+    , m_pLayoutMain(0)
     , m_pToolBar(0)
 {
     /* Prepare: */
     prepare();
+}
+
+void UIToolsToolbar::setTabBars(UITabBar *pTabBarMachine, UITabBar *pTabBarGlobal)
+{
+    /* Remember the new tab-bars: */
+    m_pTabBarMachine = pTabBarMachine;
+    m_pTabBarGlobal = pTabBarGlobal;
+
+    /* Configure tab-bar connections: */
+    connect(m_pTabBarMachine, &UITabBar::sigTabRequestForClosing,
+            this, &UIToolsToolbar::sltHandleCloseToolMachine);
+    connect(m_pTabBarMachine, &UITabBar::sigCurrentTabChanged,
+            this, &UIToolsToolbar::sltHandleToolChosenMachine);
+    connect(m_pTabBarGlobal, &UITabBar::sigTabRequestForClosing,
+            this, &UIToolsToolbar::sltHandleCloseToolGlobal);
+    connect(m_pTabBarGlobal, &UITabBar::sigCurrentTabChanged,
+            this, &UIToolsToolbar::sltHandleToolChosenGlobal);
+
+    /* Let the tab-bars know our opinion: */
+    sltHandleActionToggle();
 }
 
@@ -147,10 +167,8 @@
 {
     /* Handle known actions: */
-    const bool fShowMachine = m_pActionPool->action(UIActionIndexST_M_Tools_T_Machine)->isChecked();
-    const bool fShowGlobal  = m_pActionPool->action(UIActionIndexST_M_Tools_T_Global)->isChecked();
-    if (m_pTabBarMachine)
-        m_pTabBarMachine->setHidden(!fShowMachine);
-    if (m_pTabBarGlobal)
-        m_pTabBarGlobal->setHidden(!fShowGlobal);
+    if (m_pActionPool->action(UIActionIndexST_M_Tools_T_Machine)->isChecked())
+        emit sigShowTabBarMachine();
+    else if (m_pActionPool->action(UIActionIndexST_M_Tools_T_Global)->isChecked())
+        emit sigShowTabBarGlobal();
 }
 
@@ -228,33 +246,4 @@
         /* Configure layout: */
         m_pLayoutMain->setContentsMargins(0, 0, 0, 0);
-        m_pLayoutMain->setSpacing(10);
-
-        /* Create Machine tab-bar: */
-        m_pTabBarMachine = new UITabBar;
-        AssertPtrReturnVoid(m_pTabBarMachine);
-        {
-            /* Configure tab-bar: */
-            connect(m_pTabBarMachine, &UITabBar::sigTabRequestForClosing,
-                    this, &UIToolsToolbar::sltHandleCloseToolMachine);
-            connect(m_pTabBarMachine, &UITabBar::sigCurrentTabChanged,
-                    this, &UIToolsToolbar::sltHandleToolChosenMachine);
-
-            /* Add into layout: */
-            m_pLayoutMain->addWidget(m_pTabBarMachine);
-        }
-
-        /* Create Global tab-bar: */
-        m_pTabBarGlobal = new UITabBar;
-        AssertPtrReturnVoid(m_pTabBarGlobal);
-        {
-            /* Configure tab-bar: */
-            connect(m_pTabBarGlobal, &UITabBar::sigTabRequestForClosing,
-                    this, &UIToolsToolbar::sltHandleCloseToolGlobal);
-            connect(m_pTabBarGlobal, &UITabBar::sigCurrentTabChanged,
-                    this, &UIToolsToolbar::sltHandleToolChosenGlobal);
-
-            /* Add into layout: */
-            m_pLayoutMain->addWidget(m_pTabBarGlobal);
-        }
 
         /* Create toolbar: */
Index: /trunk/src/VBox/Frontends/VirtualBox/src/selector/UIToolsToolbar.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/selector/UIToolsToolbar.h	(revision 68229)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/selector/UIToolsToolbar.h	(revision 68230)
@@ -45,12 +45,17 @@
 signals:
 
-    /** Notify listeners about Machine tool of particular @a enmType opened. */
+    /** Notifies listeners about Machine tab-bar should be shown. */
+    void sigShowTabBarMachine();
+    /** Notifies listeners about Global tab-bar should be shown. */
+    void sigShowTabBarGlobal();
+
+    /** Notifies listeners about Machine tool of particular @a enmType opened. */
     void sigToolOpenedMachine(const ToolTypeMachine enmType);
-    /** Notify listeners about Global tool of particular @a enmType opened. */
+    /** Notifies listeners about Global tool of particular @a enmType opened. */
     void sigToolOpenedGlobal(const ToolTypeGlobal enmType);
 
-    /** Notify listeners about Machine tool of particular @a enmType closed. */
+    /** Notifies listeners about Machine tool of particular @a enmType closed. */
     void sigToolClosedMachine(const ToolTypeMachine enmType);
-    /** Notify listeners about Global tool of particular @a enmType closed. */
+    /** Notifies listeners about Global tool of particular @a enmType closed. */
     void sigToolClosedGlobal(const ToolTypeGlobal enmType);
 
@@ -60,4 +65,7 @@
       * @param  pActionPool  Brings the action-pool to take corresponding actions from. */
     UIToolsToolbar(UIActionPool *pActionPool, QWidget *pParent = 0);
+
+    /** Defines the tab-bars to control. */
+    void setTabBars(UITabBar *pTabBarMachine, UITabBar *pTabBarGlobal);
 
     /** Defines toolbar tool button @a enmStyle. */
@@ -96,7 +104,4 @@
     UIActionPool *m_pActionPool;
 
-    /** Holds the main layout instance. */
-    QHBoxLayout *m_pLayoutMain;
-
     /** Holds the Machine tab-bar instance. */
     UITabBar *m_pTabBarMachine;
@@ -104,6 +109,8 @@
     UITabBar *m_pTabBarGlobal;
 
+    /** Holds the main layout instance. */
+    QHBoxLayout *m_pLayoutMain;
     /** Holds the toolbar instance. */
-    UIToolBar *m_pToolBar;
+    UIToolBar   *m_pToolBar;
 
     /** Holds the map of opened Machine tool IDs. */
